Improve this Doc

# Error: linky:notstring
Not a string

    Expected string but received: {0}

## Description

This error occurs when linky is used with a non-empty, non-string value:

    <div ng-bind-html="42 | linky"></div>

`linky` is supposed to be used with string values only, and therefore assumes that several methods (such as `.match()`) are available on the passed in value. The value can be initialized asynchronously and therefore null or undefined won't throw this error.

If you want to pass non-string values to `linky` (e.g. Objects whose `.toString()` should be utilized), you need to manually convert them to strings.